def call(body) {
    def pipelineParams= [:]
    body.resolveStrategy = Closure.DELEGATE_FIRST
    body.delegate = pipelineParams
    body()
    def COLOR_MAP = [
	        'SUCCESS': 'good',
	        'FAILURE': 'danger',
]

    pipeline {
        agent any
        
        
        //variables environment
        environment {

                    def shortCommit = sh(returnStdout: true, script: "git log -n 1 --pretty=format:'%h'").trim()
                    def author = sh(returnStdout: true, script: "git show -s --pretty=%an").trim()
                    def url = sh(returnStdout: true, script: 'git config remote.origin.url').trim()
                    def notificationURL = "${url.replace(':', '/').replace('git@', 'https://')}"
                    def BRANCH_NAME = "${env.BRANCH_NAME}"
                    def JOB_NAME = "${env.JOB_NAME}"
                    def BUILD_NUMBER = "${env.BUILD_NUMBER}"
                    SLACK_CHANNEL_NOTIF = "${pipelineParams.slackChannelNotification}"
        }



        stages {
                            
                            stage('checkout') {
                                steps {
                                    checkout scm
                                }
                            }

                            stage('check python') {
                                steps {
                                    sh "python3 --version"
                                }
                            }
                            
                            stage('Build ') {
                                //when {
                                    //branch 'dev'
                                //}
                                steps {
                                    sh """
                                        echo 'build step'
                                        docker build -t  ${pipelineParams.imageName}:${shortCommit} .
                                    """
                                }
                            
                            }

                            stage('Push ') {
                                //when {
                                    //branch 'dev'
                                //}
                                steps {
                                    sh """
                                        docker push ${pipelineParams.imageName}:${shortCommit}
                                    """
                                }
                            }
                            //changer le tag de l'image, le remplacer sur le value.yaml
                            stage('GitOps') {
                                //when {
                                    //branch 'master'
                                //}
                                steps {
                                    script {
                                        dir('charts') {
                                            sh "rm -rf ./*"

                                            git( credentialsId: 'gitlab_credential', url: 'https://gitlab.baamtu.com/diopbe/helm-manifestfiles', branch: 'master' ) 
                                            sh """
                                            git config --global user.email "ndoumbe.diop@baamtu.com" 
                                            git config --global user.name "diopbe"

                                            yq e -i '.image.tag = "${shortCommit}"' ${pipelineParams.VALUES_FILE}
                                            git commit -am "new build for ${BRANCH_NAME} - commit hash=${shortCommit}"

                                            """
                                            withCredentials([usernamePassword(credentialsId: 'gitlab_credential', passwordVariable: 'GIT_PASSWORD', usernameVariable: 'GIT_USERNAME')]) {
                                            sh ('git remote set-url origin https://${GIT_USERNAME}:${GIT_PASSWORD}@gitlab.baamtu.com/diopbe/helm-manifestfiles')
                                            sh('git push origin master')
                                
                                        }
                                    }
                                }
                            
                            }
                     }
                            //suppression de  l'image apres pushed
                            stage('Clean ') {
                                    //when {
                                        //branch 'master'
                                    //}
                                    steps {
                                        sh """
                                            echo 'Clean'
                                            docker rmi ${pipelineParams.imageName}:${shortCommit}
                                        """
                                    }
                                } 
 
        }

          // Slack Notifications
        
        
        post {
          success {
            slackSend channel: 'demo',
            color: COLOR_MAP[currentBuild.currentResult],
            message: "*${currentBuild.currentResult}:* JOB ${env.JOB_NAME} | BUILD N° = ${env.BUILD_NUMBER}\n Plus d'infos: ${env.BUILD_URL} \n Une nouvelle image est disponible pour le projet WAQF\n Message du commit : ${env.GIT_COMMIT_MSG} \n Lien du commit: http://gitlab.baamtu.com/diopbe/tai.git/${env.GIT_COMMIT} "
         }
          failure {
            slackSend channel: 'demo',
            color: COLOR_MAP[currentBuild.currentResult],
            message: "*${currentBuild.currentResult}:* JOB ${env.JOB_NAME} | BUILD N° = ${env.BUILD_NUMBER}\n Plus d'infos: ${env.BUILD_URL} \n Message du commit : ${env.GIT_COMMIT_MSG} \n Lien du commit: http://gitlab.baamtu.com/diopbe/tai.git/${env.GIT_COMMIT}"
        }


        }

    }
  }
